
# QtFind
![QtFind Logo](https://github.com/amad3v/QtFind/raw/master/Icon.png)

:mag: **QtFind** is a graphical interface for the powerful command ***find***.

:mag: **QtFind** is designed with new comers to linux in mind.

:mag: **QtFind** also reveals the full command of the selected combination.

**find description from the man page**
*GNU find searches the directory tree rooted at each given file name by evaluating the given expression from left to right, according to the rules of precedence.*

**License**
This program comes with absolutely no warranty.
See the [GNU General Public Licence](https://www.gnu.org/licenses/gpl-3.0.html), version 3 or later for details.

**Features**
 - Default and dark (4 tones) themes
 - Show/Copy constructed command
 - Interrupt search
 - Most of find options available (refer to `man find` for more information)

**Screenshots**

*Dark theme (tone: green):*

![dark theme](https://github.com/amad3v/QtFind/raw/master/docs/main_window.png)

*Default theme:*

![default theme](https://github.com/amad3v/QtFind/raw/master/docs/main_window_l.png)

Copyright :copyright: 2019 - amad3v
